@@ -22,7 +22,8 @@ program fd_ifc
   USE cell_base,  ONLY : tpiba2, alat,omega, at, bg, ibrav, celldm
   USE ions_base,  ONLY : amass, nat, nat, atm, zv, tau, ntyp => nsp, ityp
   USE kinds,      ONLY : dp
-  USE wvfct,      ONLY : ecutwfc
+  USE gvecw,      ONLY : ecutwfc
+  USE matrix_inversion
 
   USE symm_base
   USE symme
@@ -73,7 +74,7 @@ INTEGER :: isym
 INTEGER, ALLOCATABLE  ::  sxy(:), sxz(:), syz(:)
 REAL (dp) :: ft1, ft2, ft3
 
-  REAL (dp) :: d(3,3),rd(3,3),dhex(3,3), dcub(3,3), dhexm1(3,3), da, tmp(3)
+  REAL (dp) :: d(3,3),rd(3,3),dhex(3,3), dcub(3,3), dhexm1(3,3), tmp(3)
   REAL (dp) :: accep=1.0d-5
   LOGICAL, ALLOCATABLE :: move_sl(:,:)
   LOGICAL, EXTERNAL :: eqdisp
@@ -83,7 +84,7 @@ REAL (dp) :: ft1, ft2, ft3
 
 REAL(KIND=DP), PARAMETER :: k_B=8.6173324d-5/13.60658
 LOGICAL :: ld3, verbose, offdiagonal, nodispsym, lforce0,hex, noatsym
-
+  CHARACTER(LEN=256), EXTERNAL :: trimcheck
 
   real(DP), PARAMETER :: sin3 = 0.866025403784438597d0, cos3 = 0.5d0, &
                         msin3 =-0.866025403784438597d0, mcos3 = -0.5d0
@@ -96,12 +97,13 @@ LOGICAL :: ld3, verbose, offdiagonal, nodispsym, lforce0,hex, noatsym
 ! input namelist
 !
 NAMELIST /input/ prefix, de, nrx, nrx1, nrx2, nrx3, ld3, file_force, file_force3, file_out, file_rmsd, verbose, &
-                 offdiagonal, innx, nodispsym, lforce0,hex,noatsym
+                 offdiagonal, innx, nodispsym, lforce0,hex,noatsym, outdir
 
   CALL mp_startup ( )
   CALL environment_start ( code )
 
 prefix=' '
+outdir='./'
 nrx1 = 1
 nrx2 = 1
 nrx2 = 1
@@ -122,6 +124,8 @@ hex=.false.
 CALL input_from_file ( )
 READ(5,input,IOSTAT=ios)
 IF (ios /= 0) CALL errore ('FD_IFC', 'reading input namelist', ABS(ios) )
+outdir=trim(outdir)
+tmp_dir = trimcheck( outdir )
 
 !reading the xml file
 call read_xml_file
@@ -343,7 +347,7 @@ end if
 
 if (hex) then
    d=dhex
-   call invmat (3, dhex, dhexm1, da)
+   call invmat (3, dhex, dhexm1)
 else
    d=dcub
 end if
