@@ -18,7 +18,7 @@ subroutine stop_pp
   use io_files, only: iunwfc
   use mp_global, only: mp_global_end
   USE parallel_include
-#ifdef __PARA
+#ifdef __MPI
 
   integer :: info
   logical :: op
@@ -37,13 +37,5 @@ subroutine stop_pp
 
 #endif
  
-#ifdef __T3E
-  !
-  ! set streambuffers off
-  !
-
-  call set_d_stream (0)
-#endif
-
   stop
 end subroutine stop_pp
