@@ -1,5 +1,5 @@
 !
-! Copyright (C) 2001-2008 Quantum ESPRESSO group
+! Copyright (C) 2001-2016 Quantum ESPRESSO group
 ! This file is distributed under the terms of the
 ! GNU General Public License. See the file `License'
 ! in the root directory of the present distribution,
@@ -17,10 +17,11 @@ subroutine bcast_ph_input ( )
 
   use mp, only: mp_bcast
   use mp_world, only: world_comm
+  USE control_lr, ONLY : lgamma, lrpa
   USE control_ph, ONLY : start_irr, last_irr, start_q, last_q, nmix_ph, &
-                         niter_ph, lnoloc, alpha_mix, tr2_ph, lrpa, recover, &
+                         niter_ph, lnoloc, alpha_mix, tr2_ph, recover, &
                          ldisp, reduce_io, zue, zeu, epsil, trans, &
-                         lgamma, ldiag, lqdir, search_sym,  electron_phonon, &
+                         ldiag, lqdir, search_sym,  electron_phonon, &
                          qplot, only_init, only_wfc, low_directory_check
   USE gamma_gamma, ONLY : asr
   USE disp, ONLY : nq1, nq2, nq3
@@ -37,6 +38,9 @@ subroutine bcast_ph_input ( )
   USE run_info,   ONLY : title
   USE el_phon,    ONLY : elph_nbnd_min,elph_nbnd_max,el_ph_ngauss, el_ph_nsigma, el_ph_sigma
   USE dfile_star, ONLY : drho_star, dvscf_star
+  ! YAMBO >
+  USE YAMBO,      ONLY : elph_yambo,dvscf_yambo
+  ! YAMBO <
 
   implicit none
   !
@@ -62,6 +66,10 @@ subroutine bcast_ph_input ( )
   call mp_bcast (only_wfc, meta_ionode_id, world_comm )
   call mp_bcast (only_init, meta_ionode_id, world_comm )
   call mp_bcast (search_sym, meta_ionode_id, world_comm)
+  ! YAMBO >
+  call mp_bcast (elph_yambo, meta_ionode_id, world_comm)
+  call mp_bcast (dvscf_yambo, meta_ionode_id, world_comm)
+  ! YAMBO <
   !
   ! integers
   !
