@@ -75,10 +75,10 @@ SUBROUTINE check_initial_status(auxdyn)
   USE disp,            ONLY : nqs, x_q, comp_iq, nq1, nq2, nq3, &
                               done_iq, lgamma_iq
   USE qpoint,          ONLY : xq
+  USE control_lr,      ONLY : lgamma
   USE output,          ONLY : fildyn
   USE control_ph,      ONLY : ldisp, recover, where_rec, rec_code, &
-                              start_q, last_q, current_iq, &
-                              tmp_dir_ph, lgamma, &
+                              start_q, last_q, current_iq, tmp_dir_ph, &
                               ext_recover, ext_restart, tmp_dir_phq, lqdir, &
                               start_irr, last_irr, newgrid, qplot, &
                               done_zeu, done_start_zstar, done_epsil, &
@@ -96,6 +96,9 @@ SUBROUTINE check_initial_status(auxdyn)
   USE xml_io_base,     ONLY : create_directory
   USE mp_global,       ONLY : mp_global_end
   USE el_phon,         ONLY : elph_mat
+  ! YAMBO >
+  USE YAMBO,           ONLY : elph_yambo,dvscf_yambo
+  ! YAMBO <
   !
   USE acfdtest,        ONLY : acfdt_is_active, acfdt_num_der
   !
@@ -128,7 +131,9 @@ SUBROUTINE check_initial_status(auxdyn)
            IF (.NOT. qplot) CALL q_points()
         END IF
         !
-     ELSE
+        ! YAMBO >
+     ELSE IF (.NOT.elph_yambo .AND. .NOT. dvscf_yambo) then
+        ! YAMBO <
         !
         nqs = 1
         last_q = 1
@@ -266,7 +271,8 @@ SUBROUTINE check_initial_status(auxdyn)
   !  it is not found in the running directory.
   !
   filename=TRIM(fildyn)//'0'
-  IF (ionode) THEN
+ 
+  IF (ionode.and..NOT.elph_mat) THEN
      INQUIRE (FILE = TRIM(filename), EXIST = exst)
      ierr=0
      IF ((.NOT. exst .OR. .NOT. recover).AND.ldisp) THEN
