@@ -1,5 +1,5 @@
 !
-! Copyright (C) 2001-2009 Quantum ESPRESSO group
+! Copyright (C) 2001-2016 Quantum ESPRESSO group
 ! This file is distributed under the terms of the
 ! GNU General Public License. See the file `License'
 ! in the root directory of the present distribution,
@@ -30,12 +30,13 @@ subroutine dvpsi_e (ik, ipol)
   USE uspp,            ONLY : okvan, nkb, vkb
   USE uspp_param,      ONLY : nh, nhm
   USE ramanm,          ONLY : eth_rps
-  USE eqv,             ONLY : dpsi, dvpsi, eprec
-  USE phus,            ONLY : becp1
-  USE qpoint,          ONLY : nksq, npwq
   USE units_ph,        ONLY : this_pcxpsi_is_on_file, lrcom, iucom, &
                               lrebar, iuebar
-  USE control_ph,      ONLY : nbnd_occ
+
+  USE lrus,            ONLY : becp1
+  USE qpoint,          ONLY : nksq, npwq
+  USE eqv,             ONLY : dpsi, dvpsi, eprec
+  USE control_lr,      ONLY : nbnd_occ
 
   implicit none
   !
@@ -79,7 +80,7 @@ subroutine dvpsi_e (ik, ipol)
   !    Apply -P^+_c
   !    NB it uses dvpsi as workspace
   !
-  CALL orthogonalize(dpsi, evc, ik, ik, dvpsi, npwq)
+  CALL orthogonalize(dpsi, evc, ik, ik, dvpsi, npwq, .false.)
   dpsi=-dpsi
   !
   !   dpsi contains P^+_c [H-eS,x] psi_v for the three crystal polarizations
@@ -113,7 +114,7 @@ subroutine dvpsi_e (ik, ipol)
        & " linter: root not converged ",es10.3)') &
        ik, ibnd, anorm
   !
-  CALL flush_unit( stdout )
+  FLUSH( stdout )
   deallocate (h_diag)
   !
   ! we have now obtained P_c x |psi>.
