@@ -20,16 +20,14 @@ SUBROUTINE elphon()
   USE fft_base, ONLY : dfftp, dffts
   USE noncollin_module, ONLY : nspin_mag, noncolin, m_loc
   USE lsda_mod, ONLY : nspin
-  USE phus,       ONLY : int3, int3_nc, int3_paw
   USE uspp,  ONLY: okvan
   USE paw_variables, ONLY : okpaw
   USE el_phon,  ONLY : done_elph
   USE dynmat, ONLY : dyn, w2
-  USE qpoint, ONLY : xq
   USE modes,  ONLY : npert, nirr, u
   USE uspp_param, ONLY : nhm
   USE control_ph, ONLY : trans, xmldyn
-  USE output,     ONLY : fildyn
+  USE output,     ONLY : fildyn,fildvscf
   USE io_dyn_mat, ONLY : read_dyn_mat_param, read_dyn_mat_header, &
                          read_dyn_mat, read_dyn_mat_tail
   USE units_ph, ONLY : iudyn, lrdrho, iudvscf, iuint3paw, lint3paw
@@ -37,6 +35,9 @@ SUBROUTINE elphon()
   USE mp_bands,  ONLY : intra_bgrp_comm, me_bgrp, root_bgrp
   USE mp,        ONLY : mp_bcast
   USE io_global, ONLY: stdout
+
+  USE lrus,   ONLY : int3, int3_nc, int3_paw
+  USE qpoint, ONLY : xq
   !
   IMPLICIT NONE
   !
@@ -63,19 +64,20 @@ SUBROUTINE elphon()
   ! read Delta Vscf and calculate electron-phonon coefficients
   !
   imode0 = 0
+  WRITE (6, '(5x,a)') "Reading dVscf from file "//trim(fildvscf)
   DO irr = 1, nirr
      npe=npert(irr)
      ALLOCATE (dvscfin (dfftp%nnr, nspin_mag , npe) )
      IF (okvan) THEN
-        ALLOCATE (int3 ( nhm, nhm, npe, nat, nspin_mag))
-        IF (okpaw) ALLOCATE (int3_paw (nhm, nhm, npe, nat, nspin_mag))
-        IF (noncolin) ALLOCATE(int3_nc( nhm, nhm, npe, nat, nspin))
+        ALLOCATE (int3 ( nhm, nhm, nat, nspin_mag, npe))
+        IF (okpaw) ALLOCATE (int3_paw (nhm, nhm, nat, nspin_mag, npe))
+        IF (noncolin) ALLOCATE(int3_nc( nhm, nhm, nat, nspin, npe))
      ENDIF
      DO ipert = 1, npe
         CALL davcio_drho ( dvscfin(1,1,ipert),  lrdrho, iudvscf, &
                            imode0 + ipert,  -1 )
         IF (okpaw .AND. me_bgrp==0) &
-             CALL davcio( int3_paw(:,:,ipert,:,:), lint3paw, &
+             CALL davcio( int3_paw(:,:,:,:,ipert), lint3paw, &
                                           iuint3paw, imode0 + ipert, - 1 )
      END DO
      IF (okpaw) CALL mp_bcast(int3_paw, root_bgrp, intra_bgrp_comm)
@@ -107,6 +109,7 @@ SUBROUTINE elphon()
   !
   IF (.NOT.trans) THEN
      IF (.NOT. xmldyn) THEN
+        WRITE (6, '(5x,a)') "Reading dynamics matrix from file "//trim(fildyn)
         CALL readmat (iudyn, ibrav, celldm, nat, ntyp, &
                       ityp, omega, amass, tau, xq, w2, dyn)
      ELSE
@@ -256,7 +259,8 @@ SUBROUTINE elphel (irr, npe, imode0, dvscfins)
   !      Original routine written by Francesco Mauri
   !
   USE kinds, ONLY : DP
-  USE fft_base, ONLY : dffts, tg_cgather
+  USE fft_base, ONLY : dffts
+  USE fft_parallel, ONLY : tg_cgather
   USE wavefunctions_module,  ONLY: evc
   USE io_files, ONLY: iunigk
   USE buffers,  ONLY : get_buffer
@@ -270,15 +274,17 @@ SUBROUTINE elphel (irr, npe, imode0, dvscfins)
                       comp_elph, done_elph
   USE modes, ONLY : u
   USE units_ph, ONLY : iubar, lrbar, lrwfc, iuwfc
-  USE eqv,      ONLY : dvpsi, evq
-  USE qpoint,   ONLY : igkq, npwq, nksq, ikks, ikqs, nksqtot
-  USE control_ph, ONLY : trans, lgamma, current_iq
+  USE control_ph, ONLY : trans, current_iq
   USE ph_restart, ONLY : ph_writefile
   USE spin_orb,   ONLY : domag
   USE mp_bands,   ONLY: intra_bgrp_comm, ntask_groups
   USE mp_pools,   ONLY: npool
   USE mp,        ONLY: mp_sum
 
+  USE eqv,        ONLY : dvpsi, evq
+  USE qpoint,     ONLY : igkq, npwq, nksq, ikks, ikqs, nksqtot
+  USE control_lr, ONLY : lgamma
+
   IMPLICIT NONE
   !
   INTEGER, INTENT(IN) :: irr, npe, imode0
@@ -464,17 +470,20 @@ SUBROUTINE elphsum ( )
   USE parameters,  ONLY : npk
   USE el_phon,     ONLY : el_ph_mat, done_elph, el_ph_nsigma, el_ph_ngauss, &
                           el_ph_sigma
-  USE qpoint,      ONLY : xq, nksq
-  USE modes,       ONLY : u, minus_q, nsymq, rtau, nirr
+  USE modes,       ONLY : u, nirr
   USE dynmat,      ONLY : dyn, w2
   USE io_global,   ONLY : stdout, ionode, ionode_id
   USE xml_io_base, ONLY : create_directory
   USE mp_pools,    ONLY : my_pool_id, npool, kunit
   USE mp_images,   ONLY : intra_image_comm
   USE mp,          ONLY : mp_bcast
-  USE control_ph,  ONLY : lgamma, tmp_dir_phq, xmldyn, current_iq
+  USE control_ph,  ONLY : tmp_dir_phq, xmldyn, current_iq
   USE save_ph,     ONLY : tmp_dir_save
   USE io_files,    ONLY : prefix, tmp_dir, seqopn
+  
+  USE lr_symm_base, ONLY : minus_q, nsymq, rtau
+  USE qpoint,       ONLY : xq, nksq
+  USE control_lr,   ONLY : lgamma
   !
   IMPLICIT NONE
   ! epsw = 20 cm^-1, in Ry
@@ -521,7 +530,7 @@ SUBROUTINE elphsum ( )
   COMPLEX(DP) :: el_ph_sum (3*nat,3*nat)
 
   COMPLEX(DP), POINTER :: el_ph_mat_collect(:,:,:,:)
-  REAL(DP), ALLOCATABLE :: xk_collect(:,:), wk_collect(:)
+  REAL(DP), ALLOCATABLE :: xk_collect(:,:)
   REAL(DP), POINTER :: wkfit_dist(:), etfit_dist(:,:)
   INTEGER :: nksfit_dist, rest, kunit_save
   INTEGER :: nks_real, ispin, nksqtot, irr
@@ -545,7 +554,6 @@ SUBROUTINE elphsum ( )
   nsig =el_ph_nsigma
 
   ALLOCATE(xk_collect(3,nkstot))
-  ALLOCATE(wk_collect(nkstot))
 
   ALLOCATE(deg(nsig))
   ALLOCATE(effit(nsig))
@@ -557,7 +565,6 @@ SUBROUTINE elphsum ( )
 !
      nksqtot=nksq
      xk_collect(:,1:nks) = xk(:,1:nks)
-     wk_collect(1:nks) = wk(1:nks)
      el_ph_mat_collect => el_ph_mat
   ELSE  
 !
@@ -570,12 +577,13 @@ SUBROUTINE elphsum ( )
         nksqtot=nkstot/2
      ENDIF
      ALLOCATE(el_ph_mat_collect(nbnd,nbnd,nksqtot,3*nat))
-     CALL xk_wk_collect(xk_collect,wk_collect,xk,wk,nkstot,nks)
+  ! FIXME: these two routines should be replaced by a generic routine
+     CALL xk_wk_collect(xk_collect,xk,nkstot,nks)
      CALL el_ph_collect(3*nat,el_ph_mat,el_ph_mat_collect,nksqtot,nksq)
   ENDIF
   !
   ! read eigenvalues for the dense grid
-  ! FIXME: this might be done from the xml file, not from a specialized file
+  ! FIXME: this should be done from the xml file, not from a specialized file
   ! parallel case: only first node reads
   !
   IF ( ionode ) THEN
@@ -896,7 +904,6 @@ SUBROUTINE elphsum ( )
   DEALLOCATE( effit )
   DEALLOCATE( dosfit )
   DEALLOCATE(xk_collect)
-  DEALLOCATE(wk_collect)
   IF (npool /= 1) DEALLOCATE(el_ph_mat_collect)
 
   !
@@ -927,15 +934,17 @@ SUBROUTINE elphsum_simple
   USE el_phon, ONLY : el_ph_mat, el_ph_nsigma, el_ph_ngauss, el_ph_sigma
   USE mp_pools,  ONLY : inter_pool_comm, npool
   USE mp_images, ONLY : intra_image_comm
-  USE qpoint, ONLY : xq, nksq, ikks, ikqs
   USE output, ONLY : fildyn
   USE dynmat, ONLY : dyn, w2
-  USE modes, ONLY : u, rtau, nsymq, irotmq, minus_q, nirr
+  USE modes, ONLY : u, nirr
   USE control_ph, only : current_iq, qplot
   USE lsda_mod, only : isk
   USE el_phon,   ONLY : done_elph, gamma_disp
   USE io_global, ONLY : stdout, ionode, ionode_id
   USE mp,        ONLY: mp_sum, mp_bcast
+
+  USE lr_symm_base, ONLY : rtau, nsymq, irotmq, minus_q
+  USE qpoint, ONLY : xq, nksq, ikks, ikqs
   !
   IMPLICIT NONE
   REAL(DP), PARAMETER :: eps = 20_dp/ry_to_cmm1 ! eps = 20 cm^-1, in Ry
